/*-------------------------------------------------------------------------+
| Copyright 2012 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.graphicsGL.ui.camera;

import static org.fortiss.tooling.graphicsGL.ui.util.GLPrimitives.lookAt;

import org.lwjglx.util.vector.Vector3f;

/**
 * Class representing the camera with the Z axis as up vector.
 * 
 * @author hoelzl
 */
public class Camera {

	/** The camera position. */
	protected Vector3f pos = new Vector3f(10.0f, 10.0f, 10.0f);

	/** The camera target. */
	private Vector3f target = new Vector3f();

	/** The name of the camera. */
	private final String name;

	/** Constructor. */
	public Camera(String name) {
		this.name = name;
	}

	/** Constructor. */
	public Camera() {
		this("default");
	}

	/** Returns the name of the camera. */
	public String getName() {
		return name;
	}

	/** Sets the camera position. */
	public void setPosition(float cx, float cy, float cz) {
		pos = new Vector3f(cx, cy, cz);
	}

	/** Alters the camera position with the given deltas. */
	public void alterPosition(float dx, float dy, float dz) {
		setPosition(pos.x + dx, pos.y + dy, pos.z + dz);
	}

	/** Sets the camera target. */
	public void setTarget(float tx, float ty, float tz) {
		target = new Vector3f(tx, ty, tz);
	}

	/** Alters the camera target with the given deltas. */
	public void alterTarget(float dx, float dy, float dz) {
		target.x = target.x + dx;
		target.y = target.y + dy;
		target.z = target.z + dz;
	}

	/** Applies the camera position and view target to GL before rendering starts. */
	public void applyForRendering() {
		lookAt(pos.x, pos.y, pos.z, target.x, target.y, target.z);
	}

	/** Applies the camera position and view target to GL before picking starts. */
	public void applyForPicking() {
		lookAt(pos.x, pos.y, pos.z, target.x, target.y, target.z);
	}

	/** Returns pos. */
	public Vector3f getPosition() {
		return pos;
	}
}
