/*-------------------------------------------------------------------------+
| Copyright 2016 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.ui.internal.introspection.details.handler;

import org.eclipse.jface.viewers.ColumnLabelProvider;
import org.eclipse.jface.viewers.TreeViewer;
import org.eclipse.jface.viewers.Viewer;
import org.eclipse.ui.dialogs.PatternFilter;

/**
 * Class for tree table viewer {@link PatternFilter}s.
 * Sub-classes should override {@link #basicMatch(String, int)}.
 * 
 * @author hoelzl
 */
class TableViewerPatternFilter extends PatternFilter {
	/** {@inheritDoc} */
	@Override
	protected boolean isLeafMatch(Viewer viewer, Object element) {
		TreeViewer tv = (TreeViewer)viewer;
		int nCols = tv.getTree().getColumnCount();
		boolean isMatch = false;
		for(int columnIndex = 0; columnIndex < nCols; columnIndex++) {
			ColumnLabelProvider labelProvider =
					(ColumnLabelProvider)tv.getLabelProvider(columnIndex);
			String labelText = labelProvider.getText(element);
			isMatch |= basicMatch(labelText, columnIndex);
		}
		return isMatch;
	}

	/**
	 * Matches the label in the given column.
	 * 
	 * @param labelText
	 *            Label text to be matched.
	 * @param columnIndex
	 *            Index of column for which label text has to be matched.
	 * 
	 * @return {@code true} in case of match.
	 */
	protected boolean basicMatch(String labelText, int columnIndex) {
		return wordMatches(labelText);
	}
}
