/*-------------------------------------------------------------------------+
|                                                                          |
| Copyright 2005-2011 The ConQAT Project                                   |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+-------------------------------------------------------------------------*/
package org.conqat.ide.commons.ui.databinding;

import org.eclipse.core.databinding.observable.value.AbstractObservableValue;
import org.eclipse.core.databinding.validation.ValidationStatus;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.jface.fieldassist.ControlDecoration;
import org.eclipse.jface.fieldassist.FieldDecorationRegistry;

/**
 * Observable implementation for {@link ControlDecoration}.
 * 
 * @author hummelb
 * @author $Author: deissenb $
 * @version $Rev: 34252 $
 * @levd.rating GREEN Hash: 2C228549277552521AA72E2121608565
 */
/* package */class ControlDecorationObservable extends AbstractObservableValue {

	/** The decoration. */
	private final ControlDecoration controlDecoration;

	/** Constructor. */
	public ControlDecorationObservable(ControlDecoration controlDecoration) {
		this.controlDecoration = controlDecoration;
		controlDecoration.setShowOnlyOnFocus(false);
		controlDecoration.setShowHover(true);
	}

	/** {@inheritDoc} */
	@Override
	protected void doSetValue(Object value) {
		if (!(value instanceof IStatus)) {
			value = ValidationStatus
					.error("Internal error: Invalid conversion!");
		}

		IStatus status = (IStatus) value;

		String message = status.getMessage();
		if (message == null) {
			message = "<no message>";
		}

		switch (status.getSeverity()) {
		case IStatus.OK:
			hideDecoration();
			break;
		case IStatus.WARNING:
			showDecoration(message, FieldDecorationRegistry.DEC_WARNING);
			break;
		case IStatus.INFO:
			showDecoration(message, FieldDecorationRegistry.DEC_INFORMATION);
			break;
		case IStatus.CANCEL:
		case IStatus.ERROR:
		default:
			showDecoration(message, FieldDecorationRegistry.DEC_ERROR);
			break;
		}
	}

	/** Utility method for hiding the decoration. */
	private void hideDecoration() {
		controlDecoration.hideHover();
		controlDecoration.hide();
	}

	/**
	 * Utility method for showing the decoration with a certain message and
	 * image.
	 */
	private void showDecoration(String message, String imageId) {
		controlDecoration.setDescriptionText(message);
		controlDecoration.showHoverText(message);
		controlDecoration.setImage(FieldDecorationRegistry.getDefault()
				.getFieldDecoration(imageId).getImage());
		controlDecoration.show();
	}

	/** {@inheritDoc} */
	@Override
	protected Object doGetValue() {
		return null;
	}

	/** {@inheritDoc} */
	public Object getValueType() {
		return IStatus.class;
	}

}