/*-------------------------------------------------------------------------+
|                                                                          |
| Copyright 2005-2011 The ConQAT Project                                   |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+-------------------------------------------------------------------------*/
package org.conqat.ide.commons.ui.databinding.validate;

import org.eclipse.core.databinding.validation.IValidator;
import org.eclipse.core.databinding.validation.ValidationStatus;
import org.eclipse.core.runtime.IStatus;

/**
 * Validator for checking that a numeric value is positive.
 * 
 * @author hummelb
 * @author $Author: deissenb $
 * @version $Rev: 34252 $
 * @levd.rating GREEN Hash: AC2CD54D672540CE5139AA3CD53B6DBB
 */
public class NumberPositiveValidator implements IValidator {

	/** Singleton instance. */
	public static final NumberPositiveValidator INSTANCE = new NumberPositiveValidator();

	/** {@inheritDoc} */
	public IStatus validate(Object value) {
		if (!(value instanceof Number)) {
			return ValidationStatus
					.cancel("Internal: Expected a Number, but had a "
							+ value.getClass());
		}
		if (((Number) value).doubleValue() <= 0) {
			return ValidationStatus.cancel("Value must be positive!");
		}
		return ValidationStatus.ok();
	}

}